#
# spec file for package python-h2
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-h2
Version:        3.2.0
Release:        lp152.1.1
Summary:        HTTP/2 State-Machine based protocol implementation
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/python-hyper/hyper-h2
Source0:        https://files.pythonhosted.org/packages/source/h/h2/h2-%{version}.tar.gz
BuildRequires:  %{python_module hpack >= 2.3}
BuildRequires:  %{python_module hyperframe >= 5.2.0}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-enum34 >= 1.1.6
BuildRequires:  python-rpm-macros
Requires:       python-hpack >= 2.3
Requires:       python-hyperframe >= 5.2.0
BuildArch:      noarch
%ifpython2
Requires:       python-enum34 >= 1.1.6
%endif
%python_subpackages

%description
Pure-Python implementation of a HTTP/2 protocol stack.
It’s written from the ground up to be embeddable in whatever program
you choose to use, ensuring that you can speak HTTP/2 regardless of
your programming paradigm.

%prep
%setup -q -n h2-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_changing_max_frame_size - flaky in OBS
# test_range_of_acceptable_outputs -flaky in OBS
%pytest -k 'not (test_changing_max_frame_size or test_range_of_acceptable_outputs)'

%files %{python_files}
%license LICENSE
%doc HISTORY.rst README.rst
%{python_sitelib}/h2
%{python_sitelib}/h2-%{version}-py%{python_version}.egg-info

%changelog
* Thu Feb 27 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.2.0:
  * Receiving DATA frames on closed (or reset) streams now properly emit a
    WINDOW_UPDATE to keep the connection flow window topped up.
  * h2.config.logger now uses a trace(...) function, in addition to
    debug(...).
* Wed Dec  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip one test that is flaky
* Thu Nov 14 2019 Steve Kowalik <steven.kowalik@suse.com>
- Drop unused dependancies on pytest-cov and pytest-xdist.
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.1:
  * Ignore WINDOW_UPDATE and RST_STREAM frames received after stream closure.
- Drop patch pytest5.patch
* Fri Jul 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix building with pytest5 pytest5.patch
* Fri Jul 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip flaky test in OBS:
  * test_changing_max_frame_size
* Fri Jul 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use pytest4 for now, link upstream ticket
* Tue May 14 2019 Drew Balliet <aballiet@suse.com>
- Updated testing line to current standard
- Removed symlink in install line
* Thu Mar 28 2019 John Vandenberg <jayvdb@gmail.com>
- Set URL to more useful https://github.com/python-hyper/hyper-h2
- Update to v3.1.0
  * API Changes (Backward-Incompatible)
    +  h2.connection.H2Connection.data_to_send first and only
    argument ``amt`` was renamed to ``amount``
    + Support for Python 3.3 has been removed.
  * API Changes (Backward-Compatible)
    + h2.connection.H2Connection.send_data now supports ``data``
    parameter being a ``memoryview`` object.
    + Refactor ping-related events: a h2.events.PingReceived event is
    fired when a PING frame is received and a h2.events.PingAckReceived
    event is fired when a PING frame with an ACK flag is received
    + h2.events.PingAcknowledged is deprecated in favour of the
    identical h2.events.PingAckReceived
    + Added ENABLE_CONNECT_PROTOCOL to h2.settings.SettingCodes
    + Support CONNECT requests with a ``:protocol`` pseudo header
    thereby supporting RFC 8441.
    + A limit to the number of closed streams kept in memory by the
    connection is applied. It can be configured by
    h2.connection.H2Connection.MAX_CLOSED_STREAMS
  * Debug logging when stream_id is None is now fixed and no longer errors.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Apr 21 2017 aloisio@gmx.com
- Update to version 3.0.1 (see HISTORY.rst)
- Converted to single-spec
- Enabled tests
* Tue Dec 27 2016 aloisio@gmx.com
- Initial package (2.5.1)
